<?php

//Add custom schedule for once each two minutes 
add_filter ( 'cron_schedules', 'rankie_once_6_minute' );
function rankie_once_6_minute($schedules) {
	
	// Adds once weekly to the existing schedules.
	$schedules ['rankie_once_6_minute'] = array (
			'interval' => 360,
			'display' => __ ( 'هر 6 دقيقه يک بار' ) 
	);
	return $schedules;
}

// Schedule the internal cron function
if (! wp_next_scheduled ( 'rankie_rank_hook' )) {
	
	// check if internal cron enabled or not
	$rankie_options=get_option('wp_rankie_options' , array());
	
	if(  in_array('OPT_EXTERNAL', $rankie_options)){
		return;
	}
	
	// Schedule the function	
	wp_schedule_event ( time (), 'rankie_once_6_minute', 'rankie_rank_hook' );
	
}

add_action ( 'rankie_rank_hook', 'rankie_update_rank_function_wrap_hook' );

function rankie_update_rank_function_wrap(){
	
	$wp_rankie_options=get_option('wp_rankie_options' , array('OPT_AUTO_UPDATE',));
	$disable_untill= get_option('wp_rankie_disabled_till','1401802146');
	$timeBetweenCalls = 360;
	
	if(time() < $disable_untill ){
		
		$diff_time = $disable_untill - time() ;
		
		rankie_log_new('Cron', "آپديت رنک از طریق UI کار می کند cron برای $diff_time ثانیه به خواب مي رود");
		echo 'به روزرسانی رنک از طریق UI کار می کند cron خواهد خوابید' ;
		return;
	}
 	
	if( ! in_array('OPT_AUTO_UPDATE', $wp_rankie_options)){
		rankie_log_new('Cron','به روزرسانی های خودکار رنک ها خاموش است ، اکنون به خواب می رود .');
		return;
	}
	
	// Wrap function that run updater no less than 120 seconds
	$now=time();
	$lastRun =  get_option('wp_rankie_last_run') ;
	$diff = $now - $lastRun ;
	
	if($diff > $timeBetweenCalls - 2 ) {
		
		//run it now
		update_option('wp_rankie_last_run', $now);
		rankie_update_rank_function();
		
	}else{
		
		// not yet passed interval
		$message = 'آخرین اجرا Cron از '.$diff. ' ثانیه تا '.( $timeBetweenCalls - $diff ).' ثانیه منتظر خواهد ماند .';
		rankie_log_new('Cron',$message);
		echo $message ;
		
	}
	
}

function rankie_update_rank_function_wrap_hook(){
	
	$wp_rankie_options=get_option('wp_rankie_options' , array('OPT_AUTO_UPDATE'));
	
	if(  in_array('OPT_EXTERNAL', $wp_rankie_options)){
		return;
	}
	
	rankie_log_new('Cron داخلی','هم اکنون Cron job داخلی فراخوانده شد .');
	
	// check if external cron is active, disable internal cron
	$wp_rankie_last_external_cron = get_option('wp_rankie_last_external_cron','1464176068');
	$now = time();
	
	// if external cron triggerd during last two minutes don't update
	if($now < $wp_rankie_last_external_cron + 360 ){
		rankie_log_new('Cron داخلی','یک Cron خارجی در کمتر از دو دقیقه پیش آغاز شده بود. خارج شدن');
		return;
	}
	
	rankie_log_new('Cron داخلی','در حال حاضر Cron داخلی باعث به روزرسانی رتبه می شود .');
	 
	rankie_update_rank_function_wrap();
	
	
}

function rankie_update_rank_function() {

 	echo 'یک رتبه را به روز کنید ';
 	
 	$currentTime = time();
 	$wp_rankie_update_interval = get_option('wp_rankie_update_interval','1');
 	$yesterDay = $currentTime - ( $wp_rankie_update_interval * 24 * 60 * 60 );
 	
 	 
 	//get records that was not updated from yesterday 
 	//keywords that are ranking have higher periority
 	global $wpdb;
    $query="SELECT * FROM {$wpdb->prefix}rankie_keywords where date_updated < $yesterDay and keyword_rank > 0 order by keyword_rank ASC limit 1";
    $rows=$wpdb->get_results($query);
    
    
    if(count($rows) == 0 ){
    	$query="SELECT * FROM {$wpdb->prefix}rankie_keywords where date_updated < $yesterDay and keyword_rank = 0 limit 1";
    	$rows=$wpdb->get_results($query);
    	
    }
    
    if(count($rows) > 0 ){
    	
    	rankie_log_new('آغاز کار Cron', 'Cron اجرا می شود و کلمات کلیدی واجد شرایط رتبه بندی ، وجود دارد');
    	
    	//good we have a record to update 
    	$row = $rows[0];
    	
    	echo ' به روزرسانی رکورد:'.$row->keyword_id;
    	
    	$rank= rankie_fetch_rank ( $row->keyword_id , $row->keyword );
    
    	 
    	if (isset ($rank['status']) ){
    		if($rank['status'] == 'success'  ){
    			echo ' .. به روزرسانی موفق به :'.$rank['rank'];
    			
    		}
    		
    	}else{
    		echo ' .. بدون پاسخ معتبر ';
    	}
    	
    }
	
}